==> 0.0.5.tar.gz: ojaswiftkit/OJASwiftKit/OJSViewController.swift <==
//
//  OJSViewController.swift
//  OJASwiftKitDemo
//
//  Created by luxiaoming on 2016/11/14.
//  Copyright © 2016年 luxiaoming. All rights reserved.
//

import UIKit

private var kOJSHideNavigationBarContext = 0

private let kDefaultNumberOfTouchesRequired = 2

open class OJSViewController: UIViewController {

    fileprivate var ojs_navigationBar: UINavigationBar!//保持一个引用，否则dealloc的时候直接取self.navigationController.navigationBar是nil
    fileprivate var ojs_hasAppear = false
    
    var ojs_isPushOrPopAnimating = false
    

    /// 是否要隐藏系统默认的navigationBar，默认是fasle，需要在viewDidLoad之前设置
    /// 其实是通过将navigationBar的alpha设置为0实现的
    public var ojs_shouldHideNavigationBar = false
    
    
    /// 是否隐藏返回按钮的标题，默认是true，需要在viewDidLoad之前设置
    public var ojs_shouldHideBackItemTitle = true
    
    /// 是否隐藏自定义navBarView，默认是true，需要在viewDidLoad之前设置
    public var ojs_shouldHideCustomNavBar = true
    
    public var ojs_navBarView: OJSCustomNavBarView?
    
    open lazy var debugViewController: UIViewController = OJSDebugViewController()
    
    
    open override var title: String? {
        didSet {
            self.ojs_navBarView?.update(withTitle: title)
        }
    }
    
    
    deinit {
        kOJSNotificationCenter.removeObserver(self)
        
        if ojs_shouldHideNavigationBar {
            ojs_navigationBar.removeObserver(self, forKeyPath: "alpha")
        }
    }
}

// MARK: - Lifecycle
extension OJSViewController {
    
    open override func viewDidLoad() {
        super.viewDidLoad()
        setupGesture()
        ojs_navigationBar = self.navigationController?.navigationBar
        
        if ojs_shouldHideNavigationBar {
           ojs_navigationBar.addObserver(self, forKeyPath: "alpha", options: [.new], context: &kOJSHideNavigationBarContext)
        }
        
        if ojs_shouldHideBackItemTitle {
            self.navigationItem.backBarButtonItem = UIBarButtonItem(title: "", style: .plain, target: nil, action: nil)
        }
        
        if ojs_shouldHideCustomNavBar == false {
            ojs_navBarView = OJSCustomNavBarView()
            self.view.addSubview(ojs_navBarView!)
        }
        
    }
    
    open override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        if ojs_shouldHideNavigationBar {
            ojs_hasAppear = true
            ojs_navigationBar.alpha = 0
            
        }
    }
    
    open override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        ojs_isPushOrPopAnimating = false
        
    }
    
    open override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        if ojs_shouldHideNavigationBar {
            ojs_hasAppear = false
            ojs_navigationBar.alpha = 1
        }
    }
    
    open override func viewDidDisappear(_ animated: Bool) {
        super.viewDidDisappear(animated)
        ojs_isPushOrPopAnimating = false
        
    }
    
    open override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
}


// MARK: - PrivateMethod
private extension OJSViewController {
    
    func setupGesture() {
        #if DEBUG
            
            let leftSwipeGesture = UISwipeGestureRecognizer(target: self, action: #selector(OJSViewController.handleLeftSwipeGesture(sender:)))
            leftSwipeGesture.direction = .left
            leftSwipeGesture.numberOfTouchesRequired = kDefaultNumberOfTouchesRequired
            self.view.addGestureRecognizer(leftSwipeGesture)
            
            let rightSwipeGesture = UISwipeGestureRecognizer(target: self, action: #selector(OJSViewController.handleRightSwipeGesture(sender:)))
            rightSwipeGesture.direction = .right
            rightSwipeGesture.numberOfTouchesRequired = kDefaultNumberOfTouchesRequired
            self.view.addGestureRecognizer(rightSwipeGesture)
            
            //两个手指滑动可以通过 option和shift同时按住来实现，所以长按手势没必要了
            
            
            
        #endif
    }
    
    @objc func handleLeftSwipeGesture(sender: UISwipeGestureRecognizer) -> Void {
        let nav = UINavigationController(rootViewController: debugViewController)
        self.present(nav, animated: true, completion: {
            
        })
    }
    
    @objc func handleRightSwipeGesture(sender: UISwipeGestureRecognizer) -> Void {
        let consoleViewController = OJSConsoleViewController()
        self.present(consoleViewController, animated: true, completion: { () -> Void in
            
        })
    }

}


// MARK: - StatusBar
extension OJSViewController {
    
    open override var preferredStatusBarStyle: UIStatusBarStyle {
        return .default
    }
    
    open override var prefersStatusBarHidden: Bool {
        return false
    }
}

// MARK: - Rotation
extension OJSViewController {
    
    open override var shouldAutorotate: Bool {
        return false
    }
    
    open override var supportedInterfaceOrientations: UIInterfaceOrientationMask {
         return .portrait
    }
    
    open override var preferredInterfaceOrientationForPresentation: UIInterfaceOrientation {
        return .portrait
    }
}


// MARK: - KVO
extension OJSViewController {
    open override func observeValue(forKeyPath keyPath: String?, of object: Any?, change: [NSKeyValueChangeKey : Any]?, context: UnsafeMutableRawPointer?) {
        if context == &kOJSHideNavigationBarContext && keyPath == "alpha" {
            if (ojs_navigationBar.alpha == 1 && ojs_hasAppear == true) {
                ojs_navigationBar.alpha = 0;
            }
        } else {
            super.observeValue(forKeyPath: keyPath, of: object, change: change, context: context)
        }
    }
}

==> 0.0.6.tar.gz: ojaswiftkit/OJASwiftKit/OJSViewController.swift <==
//
//  OJSViewController.swift
//  OJASwiftKitDemo
//
//  Created by luxiaoming on 2016/11/14.
//  Copyright © 2016年 luxiaoming. All rights reserved.
//

import UIKit

private var kOJSHideNavigationBarContext = 0

private let kDefaultNumberOfTouchesRequired = 2

open class OJSViewController: UIViewController {

    fileprivate var ojs_navigationBar: UINavigationBar? //保持一个引用，否则dealloc的时候直接取self.navigationController.navigationBar是nil
    fileprivate var ojs_hasAppear = false
    
    var ojs_isPushOrPopAnimating = false
    

    /// 是否要隐藏系统默认的navigationBar，默认是fasle，需要在viewDidLoad之前设置
    /// 其实是通过将navigationBar的alpha设置为0实现的
    public var ojs_shouldHideNavigationBar = false
    
    
    /// 是否隐藏返回按钮的标题，默认是true，需要在viewDidLoad之前设置
    public var ojs_shouldHideBackItemTitle = true
    
    /// 是否隐藏自定义navBarView，默认是true，需要在viewDidLoad之前设置
    public var ojs_shouldHideCustomNavBar = true
    
    public var ojs_navBarView: OJSCustomNavBarView?
    
    open lazy var debugViewController: UIViewController = OJSDebugViewController()
    
    
    open override var title: String? {
        didSet {
            self.ojs_navBarView?.update(withTitle: title)
        }
    }
    
    
    deinit {
        kOJSNotificationCenter.removeObserver(self)
        
        if ojs_shouldHideNavigationBar {
            ojs_navigationBar?.removeObserver(self, forKeyPath: "alpha")
        }
    }
}

// MARK: - Lifecycle
extension OJSViewController {
    
    open override func viewDidLoad() {
        super.viewDidLoad()
        setupGesture()
        ojs_navigationBar = self.navigationController?.navigationBar
        
        if ojs_shouldHideNavigationBar {
           ojs_navigationBar?.addObserver(self, forKeyPath: "alpha", options: [.new], context: &kOJSHideNavigationBarContext)
        }
        
        if ojs_shouldHideBackItemTitle {
            self.navigationItem.backBarButtonItem = UIBarButtonItem(title: "", style: .plain, target: nil, action: nil)
        }
        
        if ojs_shouldHideCustomNavBar == false {
            let customNavBarView = OJSCustomNavBarView()
            ojs_navBarView = customNavBarView
            self.view.addSubview(customNavBarView)
        }
        
    }
    
    open override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        if ojs_shouldHideNavigationBar {
            ojs_hasAppear = true
            ojs_navigationBar?.alpha = 0
            
        }
    }
    
    open override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        ojs_isPushOrPopAnimating = false
        
    }
    
    open override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        if ojs_shouldHideNavigationBar {
            ojs_hasAppear = false
            ojs_navigationBar?.alpha = 1
        }
    }
    
    open override func viewDidDisappear(_ animated: Bool) {
        super.viewDidDisappear(animated)
        ojs_isPushOrPopAnimating = false
        
    }
    
    open override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
}


// MARK: - PrivateMethod
private extension OJSViewController {
    
    func setupGesture() {
        #if DEBUG
            
            let leftSwipeGesture = UISwipeGestureRecognizer(target: self, action: #selector(OJSViewController.handleLeftSwipeGesture(sender:)))
            leftSwipeGesture.direction = .left
            leftSwipeGesture.numberOfTouchesRequired = kDefaultNumberOfTouchesRequired
            self.view.addGestureRecognizer(leftSwipeGesture)
            
            let rightSwipeGesture = UISwipeGestureRecognizer(target: self, action: #selector(OJSViewController.handleRightSwipeGesture(sender:)))
            rightSwipeGesture.direction = .right
            rightSwipeGesture.numberOfTouchesRequired = kDefaultNumberOfTouchesRequired
            self.view.addGestureRecognizer(rightSwipeGesture)
            
            //两个手指滑动可以通过 option和shift同时按住来实现，所以长按手势没必要了
            
            
            
        #endif
    }
    
    @objc func handleLeftSwipeGesture(sender: UISwipeGestureRecognizer) -> Void {
        let nav = UINavigationController(rootViewController: debugViewController)
        self.present(nav, animated: true, completion: {
            
        })
    }
    
    @objc func handleRightSwipeGesture(sender: UISwipeGestureRecognizer) -> Void {
        let consoleViewController = OJSConsoleViewController()
        self.present(consoleViewController, animated: true, completion: { () -> Void in
            
        })
    }

}


// MARK: - StatusBar
extension OJSViewController {
    
    open override var preferredStatusBarStyle: UIStatusBarStyle {
        return .default
    }
    
    open override var prefersStatusBarHidden: Bool {
        return false
    }
}

// MARK: - Rotation
extension OJSViewController {
    
    open override var shouldAutorotate: Bool {
        return false
    }
    
    open override var supportedInterfaceOrientations: UIInterfaceOrientationMask {
         return .portrait
    }
    
    open override var preferredInterfaceOrientationForPresentation: UIInterfaceOrientation {
        return .portrait
    }
}


// MARK: - KVO
extension OJSViewController {
    open override func observeValue(forKeyPath keyPath: String?, of object: Any?, change: [NSKeyValueChangeKey : Any]?, context: UnsafeMutableRawPointer?) {
        if context == &kOJSHideNavigationBarContext && keyPath == "alpha" {
            guard let navBar = ojs_navigationBar else { return }
            if (navBar.alpha == 1 && ojs_hasAppear == true) {
                navBar.alpha = 0;
            }
        } else {
            super.observeValue(forKeyPath: keyPath, of: object, change: change, context: context)
        }
    }
}
